@@ -1104,6 +1104,11 @@ class Order:
             self._raw = raw
 
     def to_position(self, quantity):
+        # Safety check for invalid orders
+        if self.asset is None:
+            logger.error(f"Cannot create position from order {self.identifier} - asset is None")
+            return None
+            
         position_qty = quantity
         if self.side == SELL:
             position_qty = -quantity
