@@ -1,18 +1,19 @@
 # This file contains helper functions for getting data from Polygon.io
-import logging
 import time
 from datetime import date, datetime, timedelta
-from enum import Enum
 from pathlib import Path
 import pytz
 import pandas as pd
 import pandas_market_calendars as mcal
 import requests
 from lumibot import LUMIBOT_CACHE_FOLDER, LUMIBOT_DEFAULT_PYTZ
+from lumibot.tools.lumibot_logger import get_logger
 from lumibot.entities import Asset
 from thetadata import ThetaClient
 from tqdm import tqdm
 
+logger = get_logger(__name__)
+
 WAIT_TIME = 60
 MAX_DAYS = 30
 CACHE_SUBFOLDER = "thetadata"
@@ -60,15 +61,15 @@ def get_price_data(
 
     """
 
-    # Check if we already have data for this asset in the feather file
+    # Check if we already have data for this asset in the cache file
     df_all = None
-    df_feather = None
+    df_cached = None
     cache_file = build_cache_filename(asset, timespan, datastyle)
     if cache_file.exists():
-        logging.info(f"\nLoading '{datastyle}' pricing data for {asset} / {quote_asset} with '{timespan}' timespan from cache file...")
-        df_feather = load_cache(cache_file)
-        if df_feather is not None and not df_feather.empty:
-            df_all = df_feather.copy() # Make a copy so we can check the original later for differences
+        logger.info(f"\nLoading '{datastyle}' pricing data for {asset} / {quote_asset} with '{timespan}' timespan from cache file...")
+        df_cached = load_cache(cache_file)
+        if df_cached is not None and not df_cached.empty:
+            df_all = df_cached.copy() # Make a copy so we can check the original later for differences
 
     # Check if we need to get more data
     missing_dates = get_missing_dates(df_all, asset, start, end)
@@ -82,7 +83,7 @@ def get_price_data(
     total_days = (end - start).days + 1
     total_queries = (total_days // MAX_DAYS) + 1
     description = f"\nDownloading '{datastyle}' data for {asset} / {quote_asset} with '{timespan}' from ThetaData..."
-    logging.info(description)
+    logger.info(description)
     pbar = tqdm(total=1, desc=description, dynamic_ncols=True)
 
     delta = timedelta(days=MAX_DAYS)
@@ -99,7 +100,7 @@ def get_price_data(
         interval_ms = 86400000
     else:
         interval_ms = 60000
-        logging.warning(f"Unsupported timespan: {timespan}, using default of 1 minute")
+        logger.warning(f"Unsupported timespan: {timespan}, using default of 1 minute")
 
     while start <= missing_dates[-1]:
         # If we don't have a paid subscription, we need to wait 1 minute between requests because of
@@ -111,7 +112,7 @@ def get_price_data(
         result_df = get_historical_data(asset, start, end, interval_ms, username, password, datastyle=datastyle)
 
         if result_df is None or len(result_df) == 0:
-            logging.warning(
+            logger.warning(
                 f"No data returned for {asset} / {quote_asset} with '{timespan}' timespan between {start} and {end}"
             )
 
@@ -125,7 +126,7 @@ def get_price_data(
         if asset.expiration and start > asset.expiration:
             break
 
-    update_cache(cache_file, df_all, df_feather)
+    update_cache(cache_file, df_all, df_cached)
     # Close the progress bar when done
     pbar.close()
     return df_all
@@ -188,7 +189,7 @@ def build_cache_filename(asset: Asset, timespan: str, datastyle: str = "ohlc"):
     else:
         uniq_str = asset.symbol
 
-    cache_filename = f"{asset.asset_type}_{uniq_str}_{timespan}_{datastyle}.feather"
+    cache_filename = f"{asset.asset_type}_{uniq_str}_{timespan}_{datastyle}.parquet"
     cache_file = lumibot_cache_folder / cache_filename
     return cache_file
 
@@ -234,30 +235,30 @@ def get_missing_dates(df_all, asset, start, end):
 
 def load_cache(cache_file):
     """Load the data from the cache file and return a DataFrame with a DateTimeIndex"""
-    df_feather = pd.read_feather(cache_file)
+    df = pd.read_parquet(cache_file, engine='pyarrow')
 
     # Set the 'datetime' column as the index of the DataFrame
-    df_feather.set_index("datetime", inplace=True)
+    df.set_index("datetime", inplace=True)
 
-    df_feather.index = pd.to_datetime(
-        df_feather.index
-    )  # TODO: Is there some way to speed this up? It takes several times longer than just reading the feather file
-    df_feather = df_feather.sort_index()
+    df.index = pd.to_datetime(
+        df.index
+    )  # TODO: Is there some way to speed this up? It takes several times longer than just reading the cache file
+    df = df.sort_index()
 
     # Check if the index is already timezone aware
-    if df_feather.index.tzinfo is None:
+    if df.index.tzinfo is None:
         # Set the timezone to UTC
-        df_feather.index = df_feather.index.tz_localize("UTC")
+        df.index = df.index.tz_localize("UTC")
 
-    return df_feather
+    return df
 
 
-def update_cache(cache_file, df_all, df_feather):
+def update_cache(cache_file, df_all, df_cached):
     """Update the cache file with the new data"""
-    # Check if df_all is different from df_feather (if df_feather exists)
+    # Check if df_all is different from df_cached (if df_cached exists)
     if df_all is not None and len(df_all) > 0:
         # Check if the dataframes are the same
-        if df_all.equals(df_feather):
+        if df_all.equals(df_cached):
             return
 
         # Create the directory if it doesn't exist
@@ -266,8 +267,8 @@ def update_cache(cache_file, df_all, df_feather):
         # Reset the index to convert DatetimeIndex to a regular column
         df_all_reset = df_all.reset_index()
 
-        # Save the data to a feather file
-        df_all_reset.to_feather(cache_file)
+        # Save the data to a parquet file
+        df_all_reset.to_parquet(cache_file, engine='pyarrow', compression='snappy')
 
 
 def update_df(df_all, result):
@@ -364,14 +365,14 @@ def check_connection(username: str, password: str):
             con_text = res.text
 
             if con_text == "CONNECTED":
-                logging.debug("Connected to Theta Data!")
+                logger.debug("Connected to Theta Data!")
                 connected = True
                 break
             elif con_text == "DISCONNECTED":
-                logging.debug("Disconnected from Theta Data!")
+                logger.debug("Disconnected from Theta Data!")
                 counter += 1
             else:
-                logging.info(f"Unknown connection status: {con_text}, starting theta data client")
+                logger.info(f"Unknown connection status: {con_text}, starting theta data client")
                 client = start_theta_data_client(username=username, password=password)
                 counter += 1
         except Exception as e:
@@ -379,7 +380,7 @@ def check_connection(username: str, password: str):
             counter += 1
 
         if counter > MAX_RETRIES:
-            logging.error("Cannot connect to Theta Data!")
+            logger.error("Cannot connect to Theta Data!")
             break
 
     return client, connected
@@ -400,11 +401,11 @@ def get_request(url: str, headers: dict, querystring: dict, username: str, passw
                 if "error_type" in json_resp["header"] and json_resp["header"]["error_type"] != "null":
                     # Handle "NO_DATA" error
                     if json_resp["header"]["error_type"] == "NO_DATA":
-                        logging.warning(
+                        logger.warning(
                             f"No data returned for querystring: {querystring}")
                         return None
                     else:
-                        logging.error(
+                        logger.error(
                             f"Error getting data from Theta Data: {json_resp['header']['error_type']},\nquerystring: {querystring}")
                         check_connection(username=username, password=password)
                 else:
